/********************************** (C) COPYRIGHT *******************************
 * File Name          : ch32v20x_it.c
 * Author             : WCH
 * Version            : V1.0.0
 * Date               : 2021/06/06
 * Description        : Main Interrupt Service Routines.
*********************************************************************************
* Copyright (c) 2021 Nanjing Qinheng Microelectronics Co., Ltd.
* Attention: This software (modified or not) and binary are used for 
* microcontroller manufactured by Nanjing Qinheng Microelectronics.
*******************************************************************************/
#include "ch32v20x_it.h"
#include <wchnet.h>
#include "eth_driver.h"
#include "IOT_RAM.H"
#include "Task.h"

void NMI_Handler(void) __attribute__((interrupt("WCH-Interrupt-fast")));
void HardFault_Handler(void) __attribute__((interrupt("WCH-Interrupt-fast")));
void ETH_IRQHandler(void) __attribute__((interrupt("WCH-Interrupt-fast")));
void TIM2_IRQHandler(void) __attribute__((interrupt("WCH-Interrupt-fast")));
void TIM3_IRQHandler(void) __attribute__((interrupt("WCH-Interrupt-fast")));


/*********************************************************************
 * @fn      NMI_Handler
 *
 * @brief   This function handles NMI exception.
 *
 * @return  none
 */
void NMI_Handler(void)
{
    /**/
}

/*********************************************************************
 * @fn      HardFault_Handler
 *
 * @brief   This function handles Hard Fault exception.
 *
 * @return  none
 */
void HardFault_Handler(void)
{
    printf("HardFault_Handler\r\n");
    printf("mcause:%08x\r\n",__get_MCAUSE());
    printf("mtval:%08x\r\n",__get_MTVAL());
    printf("mepc:%08x\r\n",__get_MEPC());
    while (1);
}

/*********************************************************************
 * @fn      ETH_IRQHandler
 *
 * @brief   This function handles ETH exception.
 *
 * @return  none
 */
void ETH_IRQHandler(void)
{
    WCHNET_ETHIsr();
}

/********************************************************************
 * ƣvoid TIM2_IRQHandler(void)
 * ʱ2жϺ
 * none
 * 汾V1.0
********************************************************************/
void TIM2_IRQHandler(void)
{
    WCHNET_TimeIsr(WCHNETTIMERPERIOD);
    TIM_ClearITPendingBit(TIM2, TIM_IT_Update);
}

/********************************************************************
 * ƣvoid TIM2_IRQHandler(void)
 * ʱ3жϺ
 * none
 * 汾V1.0
********************************************************************/
void TIM3_IRQHandler(void)
{
    static u8 LEDi, LEDx=0;
    u8 i;

    if(TIM_GetITStatus(TIM3, TIM_IT_Update) != RESET)           //TIM3жǷ
    {
        TIM_ClearITPendingBit(TIM3,TIM_IT_Update);               //TIM3жϹλ

        DCE_OVER_Time --;
        if( DCE_OVER_Time < 0 )
            DCE_OVER_Time = 0;

/**************************** LED״ָ̬ʾ  ******************************************************/
        switch(Net_state)
        {
            case 0 :   LEDx++;
                       if(LEDx >= 5 )           //δ
                       {
                           LEDx = 0;           // ָʾ˸ 500mS
                           GPIO_WriteBit(GPIOB, GPIO_Pin_12, (LEDi==0) ? (LEDi=Bit_SET):(LEDi=Bit_RESET));
                       }
                       break;

            case 1 :    GPIO_ResetBits( GPIOB, GPIO_Pin_12 );                //ɹָʾƳ

                        HeartBeat_Time ++;                                  //ʱۼ
                        if( HeartBeat_Time >= HeartBeat_Max_Time )
                        {
                            HeartBeat_Time = 0;                             // 
                            RUN_State  = 2;                                  //ת 
                        }
                        break;                                              // ָʾƳ

            case 2 :    GPIO_WriteBit(GPIOB, GPIO_Pin_12, (LEDi==0) ? (LEDi=Bit_SET):(LEDi=Bit_RESET));       //״̬
                        break;                                               // ָʾ˸ 100mS
        }

    }
/**************************** ʱ  *********************************************************/
    for(i=0; i<MAX_relay; i++)
    {
        if( Task_Comps[i].RUN )                 //ÿһ·״̬ʱ--
        {
            Task_Comps[i].TIMCount--;
            if(Task_Comps[i].TIMCount==0)
            {
                Task_Comps[i].TIMCount = 0 ;
                Task_Comps[i].RUN = 0;                  //ֹͣ
                //״̬ʱ Ӧ̵Ķ
                if( Task_Comps[i].Endstate == 0x00)     relay_OFF(i);
                if( Task_Comps[i].Endstate == 0xFF)     relay_ON(i);
            }
            Task_Comps[i].RelayState = Read_relaystate(i);      //Ӧ̵״̬
        }
    }
}






